==> haskell-monad-time-0.2-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-monad-time.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monad-time
version: 0.2
id: monad-time-0.2-LUGpLHgSHKFHCiGjsIZzVq
key: monad-time-0.2-LUGpLHgSHKFHCiGjsIZzVq
license: BSD3
maintainer: andrzej@scrive.com
homepage: https://github.com/scrive/monad-time
synopsis: Type class for monads which carry the notion of the current time.
description:
    '\''MonadTime'\'' type class for monads which carry the notion of the current time.
category: Control
author: Andrzej Rybczak
exposed: True
indefinite: False
exposed-modules:
    Control.Monad.Time
abi: 4ec556bd12094801e7a60ce812cb4f05
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/monad-time-0.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/monad-time-0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/monad-time-0.2
hs-libraries: HSmonad-time-0.2-LUGpLHgSHKFHCiGjsIZzVq
depends:
    base-4.10.1.0 mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH time-1.8.0.2
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH=1e76d6f7019a4b5c8c222b2fbbb06681
             time-1.8.0.2=7cc0324e0aef789d5f0780f6640c241b
haddock-interfaces: /usr/share/doc/haskell-monad-time/html/monad-time.haddock
haddock-html: /usr/share/doc/haskell-monad-time/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monad-time-0.2-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-monad-time.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monad-time
version: 0.2
id: monad-time-0.2-BTL9fQIgw9nCv5qQ1XO7Ws
key: monad-time-0.2-BTL9fQIgw9nCv5qQ1XO7Ws
license: BSD3
maintainer: andrzej@scrive.com
homepage: https://github.com/scrive/monad-time
synopsis: Type class for monads which carry the notion of the current time.
description:
    '\''MonadTime'\'' type class for monads which carry the notion of the current time.
category: Control
author: Andrzej Rybczak
exposed: True
indefinite: False
exposed-modules:
    Control.Monad.Time
abi: fdead4e02210d1346322eef1440f39f6
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/monad-time-0.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/monad-time-0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/monad-time-0.2
hs-libraries: HSmonad-time-0.2-BTL9fQIgw9nCv5qQ1XO7Ws
depends:
    base-4.10.1.0 mtl-2.2.2-8XubxMJDT8QLsstvlNotkc time-1.8.0.2
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=ada793ec1f149425d0c0689d53e1173b
             time-1.8.0.2=7cc0324e0aef789d5f0780f6640c241b
haddock-interfaces: /usr/share/doc/haskell-monad-time/html/monad-time.haddock
haddock-html: /usr/share/doc/haskell-monad-time/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
